==> gravestones-1.2.0%2B1.21.8%2BA-sources.jar: net/pneumono/gravestones/block/AestheticGravestoneBlock.java <==
package net.pneumono.gravestones.block;

import com.mojang.serialization.MapCodec;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.minecraft.block.*;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_156;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1769;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2190;
import net.minecraft.class_2237;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import net.minecraft.class_2626;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_3965;
import net.minecraft.class_5244;
import net.minecraft.class_5712;
import net.minecraft.class_5953;
import net.minecraft.class_6088;
import net.minecraft.class_7699;
import net.minecraft.class_8232;
import net.minecraft.class_8233;
import net.minecraft.class_8234;
import net.minecraft.class_8242;
import net.minecraft.class_8828;
import net.minecraft.item.*;
import net.minecraft.util.*;
import net.pneumono.gravestones.GravestonesConfig;
import net.pneumono.gravestones.content.GravestonesRegistry;
import net.pneumono.gravestones.networking.GravestoneEditorOpenS2CPayload;
import net.pneumono.pneumonocore.util.MultiVersionUtil;
import org.jetbrains.annotations.Nullable;

import java.util.Arrays;
import java.util.UUID;

public class AestheticGravestoneBlock extends AbstractGravestoneBlock {
    public AestheticGravestoneBlock(class_2251 settings) {
        super(settings);
    }

    //? if >=1.20.4 {
    public static final MapCodec<AestheticGravestoneBlock> field_46280 = AestheticGravestoneBlock.method_54094(AestheticGravestoneBlock::new);

    @Override
    protected MapCodec<? extends class_2237> method_53969() {
        return field_46280;
    }
    //?}

    //? if <1.20.6 {
    /*@SuppressWarnings("deprecation")
    @Override
    public ActionResult onUse(BlockState state, World world, BlockPos pos, PlayerEntity player, Hand hand, BlockHitResult hit) {
        ActionResult result = onUseWithItem(player.getStackInHand(hand), state, world, pos, player, hand, hit);
        if (result == ActionResult.PASS) {
            return onUse(state, world, pos, player, hit);
        } else {
            return result;
        }
    }
    *///?}

    //? if >=1.20.6 {
    @Override
    //?}
    protected /*? if >=1.21.3 {*/class_1269/*?} else if >=1.20.6 {*//*ItemActionResult*//*?} else {*//*ActionResult*//*?}*/ method_55765(class_1799 stack, class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_1268 hand, class_3965 hit) {
        class_2586 blockEntity = world.method_8321(pos);
        if (!(blockEntity instanceof AestheticGravestoneBlockEntity gravestone)) {
            //? if >=1.21.3 {
            return class_1269.field_52423;
            //?} else if >=1.20.6 {
            /*return ItemActionResult.PASS_TO_DEFAULT_BLOCK_INTERACTION;
            *///?} else {
            /*return ActionResult.PASS;
            *///?}
        }
        class_1792 item = stack.method_7909();

        boolean waxed = gravestone.isWaxed();

        if (!waxed && item instanceof class_1747 blockItem && blockItem.method_7711() instanceof class_2190 && gravestone.getHeadStack().method_7960()) {
            if (!world.method_8608()) {
                world.method_45447(null, blockEntity.method_11016(), GravestonesRegistry.SOUND_BLOCK_GRAVESTONE_ADD_SKULL, class_3419.field_15245);
                gravestone.setHeadStack(player, stack);
            }
            //? if >=1.21.3 {
            return class_1269.field_5812;
            //?} else if >=1.20.6 {
            /*return ItemActionResult.SUCCESS;
            *///?} else {
            /*return ActionResult.SUCCESS;
            *///?}
        }

        if (!world.method_8608()) {
            if (
                    item instanceof class_8234 signChangingItem &&
                    player.method_7294() &&
                    !waxed &&
                    noOtherPlayerEditing(player, gravestone) &&
                    signChangingItem.method_49801(gravestone.getText(), player) &&
                    tryTextChange(world, item, gravestone)
            ) {
                gravestone.runCommandClickEvent(player, world, pos);
                player.method_7259(class_3468.field_15372.method_14956(stack.method_7909()));
                world.method_43276(class_5712.field_28733, gravestone.method_11016(), class_5712.class_7397.method_43286(player, gravestone.method_11010()));
                //? if >=1.20.6 {
                stack.method_57008(1, player);
                //?} else {
                /*if (!player.isCreative()) {
                    stack.decrement(1);
                }
                *///?}

                //? if >=1.21.3 {
                return class_1269.field_5812;
                //?} else if >=1.20.6 {
                /*return ItemActionResult.SUCCESS;
                *///?} else {
                /*return ActionResult.SUCCESS;
                *///?}
            } else {
                //? if >=1.21.3 {
                return class_1269.field_52423;
                //?} else if >=1.20.6 {
                /*return ItemActionResult.PASS_TO_DEFAULT_BLOCK_INTERACTION;
                *///?} else {
                /*return ActionResult.PASS;
                *///?}
            }
        } else {
            if ((!(item instanceof class_8234) || !player.method_7294()) && !waxed) {
                //? if >=1.21.3 {
                return class_1269.field_21466;
                //?} else if >=1.20.6 {
                /*return ItemActionResult.CONSUME;
                *///?} else {
                /*return ActionResult.CONSUME;
                *///?}
            } else {
                //? if >=1.21.3 {
                return class_1269.field_5812;
                //?} else if >=1.20.6 {
                /*return ItemActionResult.SUCCESS;
                *///?} else {
                /*return ActionResult.SUCCESS;
                *///?}
            }
        }
    }

    private static boolean tryTextChange(class_1937 world, class_1792 item, AestheticGravestoneBlockEntity gravestone) {
        // Hardcoding all of these sucks but what else am I going to do
        if (item instanceof class_1769 dyeItem) {
            if (gravestone.changeText(text -> text.method_49862(dyeItem.method_7802()))) {
                world.method_8396(null, gravestone.method_11016(), class_3417.field_28391, class_3419.field_15245, 1.0F, 1.0F);
                return true;
            } else {
                return false;
            }
        } else if (item instanceof class_8232) {
            if (gravestone.changeText(text -> text.method_49867(true))) {
                world.method_8396(null, gravestone.method_11016(), class_3417.field_28392, class_3419.field_15245, 1.0F, 1.0F);
                return true;
            } else {
                return false;
            }
        } else if (item instanceof class_8233) {
            if (gravestone.changeText(text -> text.method_49867(false))) {
                world.method_8396(null, gravestone.method_11016(), class_3417.field_28397, class_3419.field_15245, 1.0F, 1.0F);
                return true;
            } else {
                return false;
            }
        } else if (item instanceof class_5953) {
            if (gravestone.setWaxed(true)) {
                world.method_8444(null, class_6088.field_31156, gravestone.method_11016(), 0);
                return true;
            } else {
                return false;
            }
        }
        return false;
    }

    //? >=1.20.6 {
    @Override
    //?}
    public class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit) {
        if (!(world.method_8321(pos) instanceof AestheticGravestoneBlockEntity blockEntity)) return class_1269.field_5811;

        if (world.method_8608()) {
            class_156./*? if >=1.21.3 {*/method_22320/*?} else {*//*throwOrPause*//*?}*/(new IllegalStateException("Expected to only call this on server"));
        }

        class_1799 headStack = blockEntity.getHeadStack();
        if (!blockEntity.isWaxed() && !headStack.method_7960()) {
            world.method_45447(null, blockEntity.method_11016(), GravestonesRegistry.SOUND_BLOCK_GRAVESTONE_REMOVE_SKULL, class_3419.field_15245);
            if (!player.method_7270(headStack)) {
                player.method_7328(headStack, false);
            }
            blockEntity.setHeadStack(player, class_1799.field_8037);
            return class_1269.field_5812;
        }

        boolean ranCommand = blockEntity.runCommandClickEvent(player, world, pos);
        if (blockEntity.isWaxed()) {
            world.method_45447(null, blockEntity.method_11016(), GravestonesRegistry.SOUND_BLOCK_WAXED_GRAVESTONE_INTERACT_FAIL, class_3419.field_15245);
            return class_1269.field_5812;
        } else if (ranCommand) {
            return class_1269.field_5812;
        } else if (noOtherPlayerEditing(player, blockEntity) && player.method_7294() && this.isTextLiteralOrEmpty(player, blockEntity)) {
            this.openEditScreen(player, blockEntity);
            return class_1269.field_5812;
        } else {
            return class_1269.field_5811;
        }
    }

    //? <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    //? if <1.21.5 {
    /*@Override
    public void onStateReplaced(BlockState state, World world, BlockPos pos, BlockState newState, boolean moved) {
        if (world.getBlockEntity(pos) instanceof AestheticGravestoneBlockEntity blockEntity) {
            ItemScatterer.spawn(world, pos.getX(), pos.getY(), pos.getZ(), blockEntity.getHeadStack());
        }
        super.onStateReplaced(state, world, pos, newState, moved);
    }
    *///?}

    public void openEditScreen(class_1657 player, AestheticGravestoneBlockEntity blockEntity) {
        blockEntity.setEditor(player.method_5667());
        if (player instanceof class_3222 serverPlayer) {
            class_2338 pos = blockEntity.method_11016();
            serverPlayer.field_13987.method_14364(new class_2626(MultiVersionUtil.getWorld(serverPlayer), pos));
            GravestoneEditorOpenS2CPayload payload = new GravestoneEditorOpenS2CPayload(pos);
            //? if >=1.20.6 {
            ServerPlayNetworking.send(serverPlayer, payload);
            //?} else {
            /*ServerPlayNetworking.send(serverPlayer, payload.id(), payload.write());
            *///?}
        }
    }

    private static boolean noOtherPlayerEditing(class_1657 player, AestheticGravestoneBlockEntity blockEntity) {
        UUID uUID = blockEntity.getEditor();
        return uUID == null || uUID.equals(player.method_5667());
    }

    private boolean isTextLiteralOrEmpty(class_1657 player, AestheticGravestoneBlockEntity blockEntity) {
        class_8242 signText = blockEntity.getText();
        return Arrays.stream(signText.method_49877(player.method_33793()))
                .allMatch(message -> message.equals(class_5244.field_39003) || message.method_10851() instanceof /*? if >=1.20.4 {*/class_8828/*?} else {*//*LiteralTextContent*//*?}*/);
    }

    @Override
    public boolean method_45382(class_7699 enabledFeatures) {
        return GravestonesConfig.AESTHETIC_GRAVESTONES.getValue() && super.method_45382(enabledFeatures);
    }

    @Nullable
    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new AestheticGravestoneBlockEntity(pos, state);
    }
}

==> gravestones-1.2.2%2B1.21.4%2BA-sources.jar: net/pneumono/gravestones/block/AestheticGravestoneBlock.java <==
package net.pneumono.gravestones.block;

import com.mojang.serialization.MapCodec;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.minecraft.block.*;
import net.minecraft.class_1264;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_156;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1769;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2190;
import net.minecraft.class_2237;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import net.minecraft.class_2626;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_3965;
import net.minecraft.class_5244;
import net.minecraft.class_5712;
import net.minecraft.class_5953;
import net.minecraft.class_6088;
import net.minecraft.class_7699;
import net.minecraft.class_8232;
import net.minecraft.class_8233;
import net.minecraft.class_8234;
import net.minecraft.class_8242;
import net.minecraft.class_8828;
import net.minecraft.item.*;
import net.minecraft.util.*;
import net.pneumono.gravestones.GravestonesConfig;
import net.pneumono.gravestones.content.GravestonesRegistry;
import net.pneumono.gravestones.networking.GravestoneEditorOpenS2CPayload;
import net.pneumono.pneumonocore.util.MultiVersionUtil;
import org.jetbrains.annotations.Nullable;

import java.util.Arrays;
import java.util.UUID;

public class AestheticGravestoneBlock extends AbstractGravestoneBlock {
    public AestheticGravestoneBlock(class_2251 settings) {
        super(settings);
    }

    //? if >=1.20.4 {
    public static final MapCodec<AestheticGravestoneBlock> field_46280 = AestheticGravestoneBlock.method_54094(AestheticGravestoneBlock::new);

    @Override
    protected MapCodec<? extends class_2237> method_53969() {
        return field_46280;
    }
    //?}

    //? if <1.20.6 {
    /*@SuppressWarnings("deprecation")
    @Override
    public ActionResult onUse(BlockState state, World world, BlockPos pos, PlayerEntity player, Hand hand, BlockHitResult hit) {
        ActionResult result = onUseWithItem(player.getStackInHand(hand), state, world, pos, player, hand, hit);
        if (result == ActionResult.PASS) {
            return onUse(state, world, pos, player, hit);
        } else {
            return result;
        }
    }
    *///?}

    //? if >=1.20.6 {
    @Override
    //?}
    protected /*? if >=1.21.3 {*/class_1269/*?} else if >=1.20.6 {*//*ItemActionResult*//*?} else {*//*ActionResult*//*?}*/ method_55765(class_1799 stack, class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_1268 hand, class_3965 hit) {
        class_2586 blockEntity = world.method_8321(pos);
        if (!(blockEntity instanceof AestheticGravestoneBlockEntity gravestone)) {
            //? if >=1.21.3 {
            return class_1269.field_52423;
            //?} else if >=1.20.6 {
            /*return ItemActionResult.PASS_TO_DEFAULT_BLOCK_INTERACTION;
            *///?} else {
            /*return ActionResult.PASS;
            *///?}
        }
        class_1792 item = stack.method_7909();

        boolean waxed = gravestone.isWaxed();

        if (!waxed && item instanceof class_1747 blockItem && blockItem.method_7711() instanceof class_2190 && gravestone.getHeadStack().method_7960()) {
            if (!world.method_8608()) {
                world.method_45447(null, blockEntity.method_11016(), GravestonesRegistry.SOUND_BLOCK_GRAVESTONE_ADD_SKULL, class_3419.field_15245);
                gravestone.setHeadStack(player, stack);
            }
            //? if >=1.21.3 {
            return class_1269.field_5812;
            //?} else if >=1.20.6 {
            /*return ItemActionResult.SUCCESS;
            *///?} else {
            /*return ActionResult.SUCCESS;
            *///?}
        }

        if (!world.method_8608()) {
            if (
                    item instanceof class_8234 signChangingItem &&
                    player.method_7294() &&
                    !waxed &&
                    noOtherPlayerEditing(player, gravestone) &&
                    signChangingItem.method_49801(gravestone.getText(), player) &&
                    tryTextChange(world, item, gravestone)
            ) {
                gravestone.runCommandClickEvent(player, world, pos);
                player.method_7259(class_3468.field_15372.method_14956(stack.method_7909()));
                world.method_43276(class_5712.field_28733, gravestone.method_11016(), class_5712.class_7397.method_43286(player, gravestone.method_11010()));
                //? if >=1.20.6 {
                stack.method_57008(1, player);
                //?} else {
                /*if (!player.isCreative()) {
                    stack.decrement(1);
                }
                *///?}

                //? if >=1.21.3 {
                return class_1269.field_5812;
                //?} else if >=1.20.6 {
                /*return ItemActionResult.SUCCESS;
                *///?} else {
                /*return ActionResult.SUCCESS;
                *///?}
            } else {
                //? if >=1.21.3 {
                return class_1269.field_52423;
                //?} else if >=1.20.6 {
                /*return ItemActionResult.PASS_TO_DEFAULT_BLOCK_INTERACTION;
                *///?} else {
                /*return ActionResult.PASS;
                *///?}
            }
        } else {
            if ((!(item instanceof class_8234) || !player.method_7294()) && !waxed) {
                //? if >=1.21.3 {
                return class_1269.field_21466;
                //?} else if >=1.20.6 {
                /*return ItemActionResult.CONSUME;
                *///?} else {
                /*return ActionResult.CONSUME;
                *///?}
            } else {
                //? if >=1.21.3 {
                return class_1269.field_5812;
                //?} else if >=1.20.6 {
                /*return ItemActionResult.SUCCESS;
                *///?} else {
                /*return ActionResult.SUCCESS;
                *///?}
            }
        }
    }

    private static boolean tryTextChange(class_1937 world, class_1792 item, AestheticGravestoneBlockEntity gravestone) {
        // Hardcoding all of these sucks but what else am I going to do
        if (item instanceof class_1769 dyeItem) {
            if (gravestone.changeText(text -> text.method_49862(dyeItem.method_7802()))) {
                world.method_8396(null, gravestone.method_11016(), class_3417.field_28391, class_3419.field_15245, 1.0F, 1.0F);
                return true;
            } else {
                return false;
            }
        } else if (item instanceof class_8232) {
            if (gravestone.changeText(text -> text.method_49867(true))) {
                world.method_8396(null, gravestone.method_11016(), class_3417.field_28392, class_3419.field_15245, 1.0F, 1.0F);
                return true;
            } else {
                return false;
            }
        } else if (item instanceof class_8233) {
            if (gravestone.changeText(text -> text.method_49867(false))) {
                world.method_8396(null, gravestone.method_11016(), class_3417.field_28397, class_3419.field_15245, 1.0F, 1.0F);
                return true;
            } else {
                return false;
            }
        } else if (item instanceof class_5953) {
            if (gravestone.setWaxed(true)) {
                world.method_8444(null, class_6088.field_31156, gravestone.method_11016(), 0);
                return true;
            } else {
                return false;
            }
        }
        return false;
    }

    //? >=1.20.6 {
    @Override
    //?}
    public class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit) {
        if (!(world.method_8321(pos) instanceof AestheticGravestoneBlockEntity blockEntity)) return class_1269.field_5811;

        if (world.method_8608()) {
            class_156./*? if >=1.21.3 {*/method_22320/*?} else {*//*throwOrPause*//*?}*/(new IllegalStateException("Expected to only call this on server"));
        }

        class_1799 headStack = blockEntity.getHeadStack();
        if (!blockEntity.isWaxed() && !headStack.method_7960()) {
            world.method_45447(null, blockEntity.method_11016(), GravestonesRegistry.SOUND_BLOCK_GRAVESTONE_REMOVE_SKULL, class_3419.field_15245);
            if (!player.method_7270(headStack)) {
                player.method_7328(headStack, false);
            }
            blockEntity.setHeadStack(player, class_1799.field_8037);
            return class_1269.field_5812;
        }

        boolean ranCommand = blockEntity.runCommandClickEvent(player, world, pos);
        if (blockEntity.isWaxed()) {
            world.method_45447(null, blockEntity.method_11016(), GravestonesRegistry.SOUND_BLOCK_WAXED_GRAVESTONE_INTERACT_FAIL, class_3419.field_15245);
            return class_1269.field_5812;
        } else if (ranCommand) {
            return class_1269.field_5812;
        } else if (noOtherPlayerEditing(player, blockEntity) && player.method_7294() && this.isTextLiteralOrEmpty(player, blockEntity)) {
            this.openEditScreen(player, blockEntity);
            return class_1269.field_5812;
        } else {
            return class_1269.field_5811;
        }
    }

    //? <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    //? if <1.21.5 {
    @Override
    public void method_9536(class_2680 state, class_1937 world, class_2338 pos, class_2680 newState, boolean moved) {
        if (world.method_8321(pos) instanceof AestheticGravestoneBlockEntity blockEntity) {
            class_1264.method_5449(world, pos.method_10263(), pos.method_10264(), pos.method_10260(), blockEntity.getHeadStack());
        }
        super.method_9536(state, world, pos, newState, moved);
    }
    //?}

    public void openEditScreen(class_1657 player, AestheticGravestoneBlockEntity blockEntity) {
        blockEntity.setEditor(player.method_5667());
        if (player instanceof class_3222 serverPlayer) {
            class_2338 pos = blockEntity.method_11016();
            serverPlayer.field_13987.method_14364(new class_2626(MultiVersionUtil.getWorld(serverPlayer), pos));
            GravestoneEditorOpenS2CPayload payload = new GravestoneEditorOpenS2CPayload(pos);
            //? if >=1.20.6 {
            ServerPlayNetworking.send(serverPlayer, payload);
            //?} else {
            /*ServerPlayNetworking.send(serverPlayer, payload.id(), payload.write());
            *///?}
        }
    }

    private static boolean noOtherPlayerEditing(class_1657 player, AestheticGravestoneBlockEntity blockEntity) {
        UUID uUID = blockEntity.getEditor();
        return uUID == null || uUID.equals(player.method_5667());
    }

    private boolean isTextLiteralOrEmpty(class_1657 player, AestheticGravestoneBlockEntity blockEntity) {
        class_8242 signText = blockEntity.getText();
        return Arrays.stream(signText.method_49877(player.method_33793()))
                .allMatch(message -> message.equals(class_5244.field_39003) || message.method_10851() instanceof /*? if >=1.20.4 {*/class_8828/*?} else {*//*LiteralTextContent*//*?}*/);
    }

    @Override
    public boolean method_45382(class_7699 enabledFeatures) {
        return GravestonesConfig.AESTHETIC_GRAVESTONES.getValue() && super.method_45382(enabledFeatures);
    }

    @Nullable
    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new AestheticGravestoneBlockEntity(pos, state);
    }
}
